var classIMP_1_1gsl_1_1QuasiNewton =
[
    [ "QuasiNewton", "classIMP_1_1gsl_1_1QuasiNewton.html#a5db583f97a00be6ecbea53fc6e5b499d", null ],
    [ "~QuasiNewton", "classIMP_1_1gsl_1_1QuasiNewton.html#a1a83bb25733ef0979ddc1bb45bfbb984", null ],
    [ "do_optimize", "classIMP_1_1gsl_1_1QuasiNewton.html#ab50544b512b0b8973a1d44263313b5d4", null ],
    [ "get_type_name", "classIMP_1_1gsl_1_1QuasiNewton.html#adce8da5c034c46a808c750f163286948", null ],
    [ "get_version_info", "classIMP_1_1gsl_1_1QuasiNewton.html#afcdd270312e2de59ded9b757773722cb", null ],
    [ "set_initial_step", "classIMP_1_1gsl_1_1QuasiNewton.html#ad038a968101a057290d3d9107b632569", null ],
    [ "set_line_step", "classIMP_1_1gsl_1_1QuasiNewton.html#a93009c5e662c0a595f4b6ad3a608b022", null ],
    [ "set_minimum_gradient", "classIMP_1_1gsl_1_1QuasiNewton.html#aa1b5ec763235e78c507e3b1dfc6920ec", null ]
];